Palantiri
--------

In Quenya (an Elvish tongue), Palantiri means "far-seeing".

Palantíri is an "Out of the Box" visualization tool box comprised of multiple modules.
 
Each one of the modules handles the visualization of a different model (classifier, clustering model and so on).
 
Whether you wish to visualize your module in a *Jupyter Notebook* or a web client, Palantíri is the tool for you.  

Overview
--------

version number: 0.2.0

Currently visualizing - Sklearn classifiers, clustering modules, regression models, network-x graphs, regret plots.

Installation / Usage
--------------------

To install use pip:

    $ pip install palantiri


Or clone the repo:

    $ git clone https://github.com/wolfenfeld/Palantiri.git
    $ python setup.py install